@@ -34,8 +34,8 @@ class IncidenceCategories : public IncidenceEditor
 public:
     explicit IncidenceCategories(Ui::EventOrTodoDesktop *ui);
 
-    void load(const KCalCore::Incidence::Ptr &incidence) override;
-    void save(const KCalCore::Incidence::Ptr &incidence) override;
+    void load(const KCalendarCore::Incidence::Ptr &incidence) override;
+    void save(const KCalendarCore::Incidence::Ptr &incidence) override;
     void save(Akonadi::Item &item) override;
 
     /**
